CalendarEvent class

Constructors

CalendarEvent(String id, DateTime? start, DateTime? end, {String description = '', required String name})
CalendarEvent.init()

Properties

description String
getter/setter pair
end DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
final
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant CalendarEvent other) bool
The equality operator.
override